@@ -43,6 +43,10 @@ yote.init = function( args ) {
 
     var token, root;
 
+    if( typeof sessionStorage !== 'undefined' ) {
+        token = sessionStorage.getItem( 'token' );
+    }
+    
     // cache storing objects and their meta-data
     var class2meths = {};
     var id2obj = {};
@@ -141,10 +145,12 @@ yote.init = function( args ) {
         } );
 
         // fire off an event for any update listeners
-        if( isUpdate ) {
-            for( var i in obj.listeners ) {
-                obj.listeners[i]( obj );
-            };
+        return function() {
+            if( isUpdate ) {
+                for( var i in obj.listeners ) {
+                    obj.listeners[i]( obj );
+                };
+            }
         }
 
     } //makeObj
@@ -188,14 +194,18 @@ yote.init = function( args ) {
         
         // updates
         if( res.updates ) {
+            var makeFuns = [];
             res.updates.forEach( function( upd ) {
                 if( typeof upd !== 'object' || ! upd.id ) {
                     console.warn( "Update error, was expecting object, not : '" + upd + "'" );
                 } else {
                     // good place for an update listener
-                    makeObj( upd );
+                    makeFuns.push( makeObj( upd ) );
                 }
             } ); //updates section
+            makeFuns.map( function( fun ) {
+                fun();
+            } );
         }
         
         // results
@@ -207,12 +217,16 @@ yote.init = function( args ) {
 
     // yote objects can be stored here, and interpreting
     // etc can be done here, the get & stuff
-    function reqListener( handl ) { 
+    function reqListener( succHandl, failHandl ) { 
         return function() {
-            console.log( "GOT FROM SERVER : " + this.responseText );
-            var returnVal = processRaw( this.responseText );
-            if( handl ) {
-                handl( returnVal );
+            console.log( "GOT FROM SERVER : " + this.response );
+            if( this.response ) {
+                var returnVal = processRaw( this.response );
+                if( succHandl ) {
+                    succHandl( returnVal );
+                }
+            } else if( failHandl ) {
+                failHandl( 'failed' );
             }
         };
     };
@@ -241,35 +255,69 @@ yote.init = function( args ) {
         return obj;
     }
 
-    function contact(id,action,data,handl,errhandl) { 
+    function contact_worker(id,action,data,handl,errhandl) {
+        worker = new SharedWorker( "/__/js/yote.worker.js" );
+        worker.port.start();
+
+        var readiedData = typeof data === 'undefined' || data === null ? undefined : readyObjForContact( data );
+
+        // for a single parameter, wrap into a parameter list
+        var sendData = JSON.stringify(  readiedData );
+        worker.port.onmessage = function(e) {
+            if( e.data ) {
+                var retVal = processRaw( e.data );
+                if( handl ) {
+                    handl( e.data );
+                }
+            } else if( errhandl ) {
+                errhandl( 'failed' );
+            }
+        }
+
+        worker.port.postMessage( [ id, action, readiedData ] );
+    }
+
+    function contact_server(id,action,data,handl,errhandl) { 
         var oReq = new XMLHttpRequest();
-        oReq.addEventListener("load", reqListener( handl ) );
-        oReq.addEventListener("error", errhandl );
+        oReq.addEventListener("loadend", reqListener( handl, errhandl ) );
+        oReq.addEventListener("error", function(e) { alert('error : ' + e) } );
+        oReq.addEventListener("abort", function(e) { alert('abort : ' + e) } );
 
         console.log( "CONTACTING SERVER ASYNC via url : " + yoteServerURL + 
                      '/' + id +
                      '/' + ( token ? token : '_' ) + 
                      '/' + action )
         
-        oReq.open("POST", yoteServerURL + 
-                  '/' + id +
-                  '/' + ( token ? token : '_' ) + 
-                  '/' + action, 
-                  true ); // 
+        oReq.open("POST", yoteServerURL, true );
 
         var readiedData = typeof data === 'undefined' || data === null ? undefined : readyObjForContact( data );
 
         // for a single parameter, wrap into a parameter list
-        var sendData = JSON.stringify(  readiedData );
+        var sendData = 'p=' + JSON.stringify( { pl    : readiedData, //payload
+                                                i     : id,                 
+                                                t     : token ? token : '_',
+                                                a     : action
+                                              } );
 
+        
         console.log( "About to send to server : " + sendData );
 
         // data must always be an array, though that array may have different data structures inside of it
         // as vehicles for data
+        oReq.setRequestHeader("Content-type", "application/x-www-form-urlencoded" );
         oReq.send( sendData );
 
-    }; // contact
+    }; // contact_server
 
+    var contact, worker, init_root_args = [];
+    if( args.contact == 'worker'  ) {
+        contact = contact_worker;
+        if( args.appFile ) {
+            init_root_args.push( args.appFile );
+        }
+    } else {
+        contact = contact_server;
+    }
     
     // translates text to objects
     function xform_in( item ) {
@@ -323,13 +371,22 @@ yote.init = function( args ) {
     if( ! handler ) {
         console.warn( "Warning : yote.init called without handler" );
     }
-    contact( '_', 'init_root', [], function(res) {
-        root = res[0];
+    contact( '_', 'init_root', init_root_args, function(res) {
+        root  = res[0];
         token = res[1];
+        if( typeof sessionStorage !== 'undefined' ) {
+            sessionStorage.setItem( 'token', token );
+        }
         if( handler ) {
             if( appname ) {
-                root.fetch_app( [appname], function( app ) {
-                    handler( root, app );
+                root.fetch_app( [appname], function( result ) {
+                    if( Array.isArray( result ) ) {
+                        var app = result[0];
+                        var acct = result[1];
+                    } else {
+                        app = result;
+                    }
+                    handler( root, app, acct );
                 } );
             } else {
                 handler( root );
@@ -339,6 +396,6 @@ yote.init = function( args ) {
 
 }; //yote.init
 
-yote.sameYoteObjects = function( a, b ) {
+yote.sameyoteobjects = function( a, b ) {
     return typeof a === 'object' && typeof b === 'object' && a.id === b.id;
 };
